package Linode::Longview::DataGetter::CPU;

use Linode::Longview::Util qw(jiffies2Percent slurp_file $procfs getLogger);

use Exporter 'import';
our @EXPORT_OK = (qw(get));

sub get {
	my (undef, $dataref) = @_;

	my $logger = getLogger();
	$logger->trace("Collecting CPU info");

	my $ts = time;
	my @statFile = slurp_file( $procfs . 'stat' ) or do{
		$logger->info("Couldn't check ${procfs}stat: $!");
		return $dataref;
	};
	shift @statFile;    #first line is combined, pitch it
	foreach my $line (@statFile) {
		last unless $line =~ m/^(cpu\d+)\s+/;
		my ( $user, $nice, $system, $idle, $wait )
			= ( split /\s+/, $line )[ 1 .. 5 ];
		$dataref->{LONGTERM}->{"CPU.$1.user"} = $user + $nice;
		$dataref->{LONGTERM}->{"CPU.$1.system"} = $system + 0;
		$dataref->{LONGTERM}->{"CPU.$1.wait"} = $wait + 0;
	}

	$logger->trace("Collecting load average");
	my $load = ( split( /\s/, ( slurp_file( $procfs . 'loadavg' ) )[0], 2 ) )[0] or do {
		$logger->info("Couldn't check ${procfs}loadavg: $!");
		return $dataref;
	};
	$dataref->{LONGTERM}->{"Load"} = $load + 0;

	return $dataref;
}

1;
