package Linode::Longview::DataGetter::Packages::APT;

use Linux::APT;
use feature 'state';

use Linode::Longview::Util qw(getLogger);

use Exporter 'import';
our @EXPORT_OK = ('get');

sub get {
	my ( undef, $dataref ) = @_;

	my $logger = getLogger();
	$logger->trace("Entering APT module");

	if(checkRunning($dataref)){
		$logger->debug("Another instance of apt-get is already running, skip package this pass");
		$dataref->{INSTANT}->{Packages} = [];
		return $dataref;
	}
	my $apt = Linux::APT->new();
	if(shouldUpdate()){
		$logger->trace("Running apt-get update before reporting packages");
		$apt->update();
	}
	my $pkgs = $apt->toupgrade()->{packages};
	$dataref->{INSTANT}->{Packages} = [
		map {
			{   name    => $_,
				current => $pkgs->{$_}{current},
				new     => $pkgs->{$_}{new} }
		} keys %$pkgs
	];
	return $dataref;
}

sub shouldUpdate {
	state $nextRun;
	return 0 if((defined $nextRun) && ($nextRun > time));
	$nextRun = time + 86400; #Only actually hit the mirrors once every 24 hours.
	return 1;
}

sub checkRunning {
	my $dataref = shift;
	return grep(m/Processes\.apt-get/,keys %{$dataref->{LONGTERM}});
}

1;
