package Linode::Longview::DataGetter::SysInfo;

use Sys::Hostname;
use Linode::Longview::Util qw($version getLogger);

use Exporter;
@ISA       = qw(Exporter);
@EXPORT_OK = qw(get);

use Linode::Longview::Util qw(slurp_file detect_system $procfs $sysfs $arch);
use Linux::Distribution qw(distribution_name distribution_version);
use POSIX qw(uname);

sub get {
	my (undef, $dataref) = @_;

	my $logger = getLogger();
	$logger->trace("Collecting SysInfo");

	$dataref->{INSTANT}->{"SysInfo.os.dist"}			= 'unknown';
	$dataref->{INSTANT}->{"SysInfo.os.distversion"} 	= 'unknown';
	if ( my $distro = distribution_name() ) {
		$dataref->{INSTANT}->{"SysInfo.os.dist"} 		= ucfirst($distro);
		$dataref->{INSTANT}->{"SysInfo.os.distversion"} = distribution_version();
	}

	$dataref->{INSTANT}->{"SysInfo.client"} = $version;

	my ( $sysname, undef, $release, $version, $machine ) = uname();
	$dataref->{INSTANT}->{"SysInfo.kernel"} = "$sysname $release";

	my @cpu_info = slurp_file( $procfs . 'cpuinfo' )
		or do {
			$logger->info("Couldn't read ${procfs}cpuinfo: $!");
			return $dataref;
	};

	$dataref->{INSTANT}->{"SysInfo.cpu.cores"} = grep {/^processor/} @cpu_info;
	#<<<
	($dataref->{INSTANT}->{"SysInfo.cpu.type"} = (map { /^model name\s+:(?<model>.*)$/; $+{model} || ()} @cpu_info)[0]) =~ s/^\s+//;
	#>>>
	$dataref->{INSTANT}->{"SysInfo.cpu.type"} =~ s/\s\s+/ /g;
	$dataref->{INSTANT}->{"SysInfo.type"} = detect_system();
	$dataref->{INSTANT}->{"SysInfo.arch"} = $arch;
	$dataref->{INSTANT}->{"SysInfo.hostname"} = hostname;

	$dataref->{INSTANT}->{"Uptime"} = ( split( /\s+/, slurp_file( $procfs . 'uptime' ) ) )[0] or $logger->info("Couldn't check ${procfs}uptime: $!");
	$dataref->{INSTANT}->{"Uptime"} = $dataref->{INSTANT}->{"Uptime"} +0;

	return $dataref;
}

1;
